@@ -1,6 +1,6 @@
 /*
  * ndisc.c - ICMPv6 neighbour discovery command line tool
- * $Id: ndisc.c 620 2008-04-24 20:33:56Z remi $
+ * $Id: ndisc.c 657 2010-10-31 20:51:32Z remi $
  */
 
 /*************************************************************************
@@ -27,7 +27,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h> /* div() */
-#include <inttypes.h>
+#include <inttypes.h> /* uint8_t */
 #include <limits.h> /* UINT_MAX */
 #include <locale.h>
 #include <stdbool.h>
@@ -364,7 +364,7 @@ parseroute (const uint8_t *opt)
 	if (inet_ntop (AF_INET6, &dst, str, sizeof (str)) == NULL)
 		return -1;
 
-	printf (_(" Route                    : %s/%u\n"), str, (unsigned)plen);
+	printf (_(" Route                    : %s/%"PRIu8"\n"), str, plen);
 	printf (_("  Route preference        :       %6s\n"), pref_i2n (opt[3]));
 	fputs (_("  Route lifetime          : "), stdout);
 	print32time (((const uint32_t *)opt)[1]);
@@ -601,10 +601,14 @@ recvadv (int fd, const struct sockaddr_in6 *tgt, unsigned wait_ms,
 
 		/* receives an ICMPv6 packet */
 		// TODO: use interface MTU as buffer size
-		uint8_t buf[1460];
+		union
+		{
+			uint8_t  b[1460];
+			uint64_t align;
+		} buf;
 		struct sockaddr_in6 addr;
 
-		val = recvfromLL (fd, buf, sizeof (buf), MSG_DONTWAIT, &addr);
+		val = recvfromLL (fd, &buf, sizeof (buf), MSG_DONTWAIT, &addr);
 		if (val == -1)
 		{
 			if (errno != EAGAIN)
@@ -617,7 +621,7 @@ recvadv (int fd, const struct sockaddr_in6 *tgt, unsigned wait_ms,
 		 && (addr.sin6_scope_id != tgt->sin6_scope_id))
 			continue;
 
-		if (parseadv (buf, val, tgt, (flags & NDISC_VERBOSE) != 0) == 0)
+		if (parseadv (buf.b, val, tgt, (flags & NDISC_VERBOSE) != 0) == 0)
 		{
 			if (flags & NDISC_VERBOSE)
 			{
@@ -769,7 +773,7 @@ static int
 version (void)
 {
 	printf (_(
-"ndisc6: IPv6 Neighbor/Router Discovery userland tool %s (%s)\n"), VERSION, "$Rev: 620 $");
+"ndisc6: IPv6 Neighbor/Router Discovery userland tool %s (%s)\n"), VERSION, "$Rev: 657 $");
 	printf (_(" built %s on %s\n"), __DATE__, PACKAGE_BUILD_HOSTNAME);
 
 	printf (_("Configured with: %s\n"), PACKAGE_CONFIGURE_INVOCATION);
