@@ -1,6 +1,6 @@
 /*
  * traceroute.c - TCP/IPv6 traceroute tool
- * $Id: traceroute.c 609 2008-03-23 09:12:19Z remi $
+ * $Id: traceroute.c 651 2010-05-01 08:08:53Z remi $
  */
 
 /*************************************************************************
@@ -29,6 +29,7 @@
 #include <stdlib.h> /* div() */
 #include <limits.h>
 #include <stdbool.h>
+#include <stdint.h>
 #include <time.h> /* nanosleep() */
 #include <assert.h>
 
@@ -1007,7 +1008,7 @@ traceroute (const char *dsthost, const char *dstport,
 	memset (&dst, 0, sizeof (dst));
 	if (connect_proto (protofd, &dst, dsthost, dstport, srchost, srcport))
 		goto error;
-	printf (_("%u hops max, "), max_ttl);
+	printf (ngettext ("%u hop max, ", "%u hops max, ", max_ttl), max_ttl);
 
 #ifdef SO_ATTACH_FILTER
 	{
@@ -1058,7 +1059,8 @@ traceroute (const char *dsthost, const char *dstport,
 	if (packet_len < overhead)
 		packet_len = overhead;
 
-	printf (_("%lu byte packets\n"), (unsigned long)packet_len);
+	printf (ngettext ("%zu byte packets\n", "%zu bytes packets\n", packet_len),
+            packet_len);
 	packet_len -= overhead;
 
 	struct timespec delay_ts;
@@ -1248,7 +1250,7 @@ static int
 version (void)
 {
 	printf (_(
-"traceroute6: TCP & UDP IPv6 traceroute tool %s (%s)\n"), VERSION, "$Rev: 609 $");
+"traceroute6: TCP & UDP IPv6 traceroute tool %s (%s)\n"), VERSION, "$Rev: 651 $");
 	printf (_(" built %s on %s\n"), __DATE__, PACKAGE_BUILD_HOSTNAME);
 	printf (_("Configured with: %s\n"), PACKAGE_CONFIGURE_INVOCATION);
 	puts (_("Written by Remi Denis-Courmont\n"));
